@@ -9,7 +9,8 @@
 #' per time step (e.g., Scherbaum et al., 2010).
 #' 
 #' \code{mt_plot_riverbed} usually is applied to time-normalized trajectory data
-#' as all trajectories must contain the same number of values.
+#' as all trajectories must contain the same number of values (if
+#' \code{na.rm=FALSE}, the default).
 #' 
 #' @param data mousetrap data object containing the data to be plotted.
 #' @param use character string specifying the set of trajectories to use in the
@@ -37,6 +38,11 @@
 #'   color. If a vector of length 2 is provided, the first value will be used as
 #'   the color for the major grid lines, the second value for the minor grid
 #'   lines. If set to \code{NA}, no grid lines are plotted.
+#' @param na.rm logical specifying whether missing values should be removed.
+#'   This is not done by default, because generally riverbed plots are generated
+#'   from preprocess trajectories (e.g., time-normalized trajectories) that all
+#'   have the same length (i.e., the same number of steps).
+#' 
 #'   
 #' @references Scherbaum, S., Dshemuchadse, M., Fischer, R., & Goschke, T.
 #'   (2010). How decisions evolve: The temporal dynamics of action selection.
@@ -74,15 +80,15 @@
 #' }
 #' 
 #' @author
-#' Felix Henninger (\email{mailbox@@felixhenninger.com})
+#' Felix Henninger
 #'
-#' Pascal J. Kieslich (\email{kieslich@@psychologie.uni-mannheim.de})
+#' Pascal J. Kieslich
 #' 
 #' @export
 mt_plot_riverbed <- function(data, use='tn_trajectories', 
                              y='xpos', y_range=NULL, y_bins=250,
                              facet_row=NULL, facet_col=NULL, facet_data='data',
-                             grid_colors=c("gray30","gray10")) {
+                             grid_colors=c("gray30","gray10"), na.rm=FALSE) {
   
   # Extract data from mousetrap data object
   trajectories <- extract_data(data=data, use=use)
@@ -95,7 +101,7 @@ mt_plot_riverbed <- function(data, use='tn_trajectories',
   # Calculate range of values on y axis,
   # if not specified explicitly
   if (is.null(y_range)) {
-    y_range <- range(trajectories[,,y])
+    y_range <- range(trajectories[,,y],na.rm=na.rm)
   }
   
   # Compute breaks based on the number of bins required
@@ -177,13 +183,16 @@ mt_plot_riverbed <- function(data, use='tn_trajectories',
     }
   }
   
+  # Remove NAs
+  riverbed <- riverbed[is.na(riverbed[,"alpha"])==FALSE,]
+  
   # Remove zero frequencies (coded in alpha)
   riverbed <- riverbed[riverbed[,"alpha"]==TRUE,]
   
   # Create plot output
   output <- ggplot2::ggplot(ggplot2::aes_string(x='value_x', y='value_y', 
       fill='frequency'), data=riverbed) +
-    ggplot2::geom_raster() +
+    ggplot2::geom_tile() +
     ggplot2::scale_fill_gradientn(colours=rev(RColorBrewer::brewer.pal(9, "YlOrRd")),
       name='Frequency', trans='log', labels=scales::percent) +
     ggplot2::scale_alpha_manual(values=c(0, 1), guide='none') +
